@echo off
chcp 65001 >nul
title 座位分配系统 v2.0

:: 设置颜色
color 0F

echo.
echo ==========================================
echo         座位分配系统 v2.0
echo ==========================================
echo.
echo 正在检查运行环境...
echo.

:: 检查可执行文件是否存在
if not exist "座位分配系统.exe" (
    echo [错误] 未找到 座位分配系统.exe 文件
    echo.
    echo 请确保以下文件在同一目录下:
    echo - 座位分配系统.exe
    echo - 人员信息.xlsx
    echo - 座位信息.xlsx
    echo.
    pause
    exit /b 1
)

echo [成功] 程序文件检查通过

:: 检查Excel文件
echo 正在扫描Excel文件...

:: 计算xlsx文件数量
set count=0
for %%f in (*.xlsx) do (
    :: 排除输出和示例文件
    echo "%%f" | findstr /v /i "最终分配\|分配日志\|示例\|temp\|backup" >nul
    if not errorlevel 1 (
        set /a count+=1
        echo 发现文件: %%f
    )
)

if %count% equ 0 (
    echo.
    echo [错误] 未找到Excel数据文件
    echo.
    echo 请确保当前目录下有Excel数据文件:
    echo 1. 人员信息文件 (5-6列): 姓名、证件类型、证件号、手机号、备注等
    echo 2. 座位信息文件 (10+列): 区域、楼层、排号、座位号等  
    echo.
    echo 提示: 程序会自动识别文件类型，无需固定文件名
    pause
    exit /b 1
)

if %count% gtr 2 (
    echo.
    echo [警告] 发现超过2个Excel文件
    echo 为避免识别混淆，请确保目录下只有2个数据文件
    echo 程序会自动排除输出文件和示例文件
    echo.
    echo 当前Excel文件:
    for %%f in (*.xlsx) do echo   %%f
    echo.
    echo 请移除多余文件后重试
    pause
    exit /b 1
)

echo [成功] 找到 %count% 个Excel文件，程序将自动识别文件类型

echo.
echo ==========================================
echo           开始运行程序
echo ==========================================
echo.
echo 所有检查通过，正在启动座位分配系统...
echo 请等待程序运行完成...
echo.

:: 运行程序并捕获错误
"座位分配系统.exe"
set "exit_code=%ERRORLEVEL%"

echo.
echo ==========================================
echo           运行结果
echo ==========================================
echo.

if %exit_code% equ 0 (
    echo [成功] 程序运行成功!
    echo.
    echo 输出文件说明:
    echo - 座位信息_最终分配.xlsx: 最终座位分配结果
    echo - 最终座位分配日志.xlsx: 详细分配记录
    echo - seat_allocation_log.txt: 运行日志文件
    echo.
    echo 您可以用Excel打开xlsx文件查看结果
) else (
    echo [错误] 程序运行出现错误 (错误代码: %exit_code%)
    echo.
    echo 可能的原因:
    echo 1. 数据文件格式不正确
    echo 2. 文件权限不足
    echo 3. 磁盘空间不足
    echo 4. 缺少必要的依赖
    echo.
    echo 请查看 seat_allocation_log.txt 获取详细错误信息
)

echo.
echo 按任意键退出...
pause >nul 